@@ -26,17 +26,20 @@ The ``func`` module provides functions for functions that do the heavy-lifting:
 
    cal_koff
    cal_survival_func
+   calculate_koff_wrapper
    Duration
    cal_contact_residues
-   cal_interaction_frequency
+   cal_occupancy
+   cal_lipidcount
    get_node_list
    collect_bound_poses
    vectorize_poses
    calculate_scores
    write_bound_poses
+   calculate_surface_area_wrapper
+   analyze_pose_wrapper
    cluster_DBSCAN
    cluster_KMeans
-   calculate_site_surface_area
 
 """
 
