@@ -26,47 +26,89 @@ __all__ = ["cal_koff", "cal_survival_func", "calculate_koff_wrapper"]
 
 
 def cal_koff(durations, t_total, timestep, nbootstrap=10, initial_guess=[1., 1., 1., 1.], cap=True):
-    """Calculate residence time based on collected interaction durations via a normalised survival function.
+    r"""Calculate residence time and koff.
+
+    This function calculates the normalized survival time correlation function of the given list of durations, and fits t
+    he survival function to a bi-exponential curve [1]_.
+
+    The survival time correlation function σ(t) is calculated as follow
+
+    .. math::
+
+        \sigma(t) = \frac{1}{N_{j}} \frac{1}{T-t} \sum_{j=1}^{N_{j}} \sum_{v=0}^{T-t}\tilde{n}_{j}(v, v+t)
+
+    where T is the length of the simulation trajectory, :math:`N_{j}` is the total number of lipid contacts and
+    :math:`\sum_{v=0}^{T-t} \tilde{n}_{j}(v, v+t)` is a binary function that takes the value 1 if the contact of
+    lipid j lasts from time ν to time v+t and 0 otherwise. The values of :math:`\sigma(t)` are calculated for every
+    value of t from 0 to T ns, for each time step of the trajectories, and normalized by dividing by :math:`\sigma(t)`,
+    so that the survival time-correlation function has value 1 at t = 0.
+
+    The normalized survival function is then fitted to a biexponential to model the long and short decays of
+    lipid relaxation:
+
+    .. math::
+        \sigma(t) \sim A e^{-k_{1} t}+B e^{-k_{2} t}\left(k_{1} \leq k_{2}\right)
+
+    This function then takes :math:`k_{1}` as the the dissociation :math:`k_{off}`, and calculates the residence time as
+    :math:`\tau=1 / k_{o f f}`.
+
+    This function also measures the :math:`r^{2}` of the biexponential fitting to the survival function to show the
+    quality of the :math:`k_{off}` estimation. In addition, it bootstraps the contact durations and measures the
+    :math:`k_{off}` of the bootstrapped data, to report how well lipid contacts are sampled from simulations. The
+    lipid contact sampling, the curve-fitting and the bootstrap results can be conveniently checked via the
+    :math:`k_{off}` plot. The :math:`r^{2}`, :math:`\sigma(t)` and bootstrapped data are stored in the returned data
+    ``properties``.
 
     Parameters
     ----------
     durations : array_like
-            Collected interaction durations
+            A list of interaction durations
+
     t_total : scalar
-            The duration or length, or the longest if using multiple simulations of different durations/lengths, of the
+            The duration, or the longest if using multiple simulations of different durations, of the
             simulation trajectories. Should be in the same time unit as durations.
+
     timestep : scalar
-            :math:`\Delta t` of the survival function :math:`\sigma`. Often take the time step of the simulation
+            :math:`\Delta t` of the survival function :math:`\sigma`. Often takes the time step of the simulation
             trajectories or multiples of the trajectory time step. Should be in the same time unit as durations.
+
     nbootstrap : int, optional, default=10
-            Number of bootstrapping for calculation. The default is 10.
+            Number of bootstrapping. The default is 10.
+
     initial_quess : list, optional, default=(1., 1., 1., 1.)
-            The initial guess for bi-exponential fitting to the survival function that is used by
-            scipy.optimize.curve_fit.
+            The initial guess for fitting of a bi-exponential curve to the survival function. Used by
+            `scipy.optimize.curve_fit <https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.curve_fit.html>`_.
+
     cap : bool, optional, default=True
-            Cap the returned residence time to t_total.
+            Cap the returned residence time to ``t_total``. This is useful for cases of poor samplings where the curve fitting
+            may be bad and the calculated residence times may be unrealistically large.
 
     Returns
     ----------
     koff : scalar
-            The calculated koff. In the unit of "tu"^-1 in which "tu" is the time unit used by the provided durations.
-    res_time : scalar
-            The calculated residence time. In the same time unit as the provided durations.
-    properties : dict
-            A dictionary of all the computed values, including the original and bootstrapped koffs, residence times, ks 
-            of the bi-expo curve :math:`y=A*e^{(-k_1*x)}+B*e^{(-k_2*x)}` and :math:`R^2`.
+            The calculated koff. In the unit of :math:`{timeunit^{-1}}` in which :math:`{timeunit}` is the same as
+            what is used in ``durations``.
 
-    Notes
-    ----------
-    See `cal_survival_func` for the definition of the survival function :math:`\sigma`.
-    A bi-exponential :math:`y=Ae^{-k_1\Delta t}+Be^{-k_2\Delta t}` is used to fit the survival rate curve. The two `ks`
-    are stored in the returned dictionary of properties. The smaller k is regarded as the interaction koff and
-    the residence time is calculated as :math:`{\frac{1}{koff}}`.
+    res_time : scalar
+            The calculated residence time. In the same time unit as used by ``durations``.
+
+    properties : dict
+            A dictionary of all the computed values, including the original and bootstrapped koffs, residence times, ks
+            of the bi-expo curve :math:`y=A*e^{(-k_1*x)}+B*e^{(-k_2*x)}` and :math:`R^2`.
 
     See also
     -----------
     pylipid.plot.plot_koff
             Plotting function for interaction durations and the calculated survival function.
+    pylipid.api.LipidInteraction.compute_residue_koff
+        Calculate interaction koff and residence time for residues.
+    pylipid.api.LipidInteraction.compute_site_koff
+        Calculate interaction koff and residence time for binding sites.
+
+    References
+    -----------
+    .. [1] García, Angel E.Stiller, Lewis. Computation of the mean residence time of water in the hydration shells
+           of biomolecules. 1993. Journal of Computational Chemistry.
 
     """
     # calculate original residence time
@@ -119,15 +161,30 @@ def cal_koff(durations, t_total, timestep, nbootstrap=10, initial_guess=[1., 1.,
 
 
 def cal_survival_func(durations, t_total, delta_t_list):
-    """Compute the normalised survival function :math:`\sigma` based on the given durations
+    r"""Compute the normalised survival function.
+
+    Calculate the normalized survival time correlation function of the given list of durations.
+    The survival time correlation function σ(t) is calculated as follow
+
+    .. math::
+
+        \sigma(t) = \frac{1}{N_{j}} \frac{1}{T-t} \sum_{j=1}^{N_{j}} \sum_{v=0}^{T-t}\tilde{n}_{j}(v, v+t)
+
+    where T is the length of the simulation trajectory, :math:`N_{j}` is the total number of lipid contacts and
+    :math:`\sum_{v=0}^{T-t} \tilde{n}_{j}(v, v+t)` is a binary function that takes the value 1 if the contact of
+    lipid j lasts from time ν to time v+t and 0 otherwise. The values of :math:`\sigma(t)` are calculated for every
+    value of t from 0 to T ns, for each time step of the trajectories, and normalized by dividing by :math:`\sigma(t)`,
+    so that the survival time-correlation function has value 1 at t = 0.
 
     Parameters
     -----------
     durations : array_like
-            Collected interaction durations
+            A list of contact durations.
+
     t_total : scalar
             The duration or length, or the longest if using multiple simulations of different durations/lengths, of the
             simulation trajectories. Should be in the same time unit as durations.
+
     delta_t_list : array_like
             The list of :math:`\Delta t` for the survival function :math:`\sigma` to check the interaction survival rate.
 
@@ -136,17 +193,10 @@ def cal_survival_func(durations, t_total, delta_t_list):
     survival_func : dict
             The survival function :math:`\sigma` stored in a dictionary {delta_t: survival rate}.
 
-    Notes
+    See also
     -----------
-    The normalised survival function
-
-    .. math::
-            \sigma\left(t\right)=\frac{1}{N_j}\frac{1}{T-t}\sum_{j=1}^{N_j}\sum_{\nu=0}^{T}{{\tilde{n}}_j\left(\nu,v+t\right)}
-
-    where `T` is the duration of simulation trajectories (`t_total`), :math:`N_j` the number of interactions collected
-    from simulations (i.e. len(durations)), and :math:`{\tilde{n}}_j(\nu,v+\Delta t)` is a function that takes the
-    value 1 if an interaction appeared for a continuous duration of :math:`\Delta t` after forming the contact at time v,
-    and takes the value 0 if otherwise.
+    pylipid.func.cal_koff
+        Calculate residence time and koff.
 
     """
     num_of_contacts = len(durations)
